"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFixtures2 = getFixtures2;

var _path = _interopRequireDefault(require("path"));

var _FixtureLoader = require("react-cosmos-shared2/FixtureLoader");

var _fixtureTree = require("react-cosmos-shared2/fixtureTree");

var _react = require("react-cosmos-shared2/react");

var _url = require("react-cosmos-shared2/url");

var _url2 = _interopRequireDefault(require("url"));

var _playgroundHtml = require("./shared/playgroundHtml");

var _userDeps = require("./shared/userDeps");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getFixtures2(cosmosConfig) {
  var fixturesDir = cosmosConfig.fixturesDir,
      fixtureFileSuffix = cosmosConfig.fixtureFileSuffix,
      rootDir = cosmosConfig.rootDir;
  var fixtureInfo = [];

  var _getUserModules = (0, _userDeps.getUserModules)(cosmosConfig),
      fixtureExportsByPath = _getUserModules.fixtureExportsByPath,
      decoratorsByPath = _getUserModules.decoratorsByPath;

  var fixtureNamesByPath = (0, _react.getFixtureNamesByPath)(fixtureExportsByPath);
  var fixtureTree = (0, _fixtureTree.createFixtureTree)({
    fixtures: fixtureNamesByPath,
    fixturesDir: fixturesDir,
    fixtureFileSuffix: fixtureFileSuffix
  });
  var flatFixtureTree = (0, _fixtureTree.flattenFixtureTree)(fixtureTree);
  flatFixtureTree.forEach(function (_ref) {
    var fixtureId = _ref.fixtureId,
        cleanPath = _ref.cleanPath;
    var rawFileName = fixtureId.path.split('/').pop();
    var cleanFileName = (0, _fixtureTree.removeFixtureNameSuffix)((0, _fixtureTree.removeFixtureNameExtension)(rawFileName), fixtureFileSuffix);
    var fixtureExport = fixtureExportsByPath[fixtureId.path];
    var fixture = fixtureId.name === null ? fixtureExport : fixtureExport[fixtureId.name];
    fixtureInfo.push({
      absoluteFilePath: _path.default.join(rootDir, fixtureId.path),
      fileName: cleanFileName,
      getElement: createFixtureElementGetter(fixture, fixtureId.path, decoratorsByPath),
      name: fixtureId.name,
      playgroundUrl: getPlaygroundUrl(cosmosConfig, fixtureId),
      relativeFilePath: fixtureId.path,
      rendererUrl: getRendererUrl(cosmosConfig, fixtureId),
      treePath: cleanPath
    });
  });
  return fixtureInfo;
}

function getPlaygroundUrl(cosmosConfig, fixtureId) {
  var host = getPlaygroundHost(cosmosConfig);
  var query = (0, _url.stringifyPlaygroundUrlQuery)({
    fixtureId: fixtureId
  });
  return "".concat(host, "/?").concat(query);
}

function getRendererUrl(cosmosConfig, fixtureId) {
  var publicUrl = cosmosConfig.publicUrl;
  var host = getPlaygroundHost(cosmosConfig);

  var urlPath = _url2.default.resolve(publicUrl, _playgroundHtml.RENDERER_FILENAME);

  var query = (0, _url.stringifyRendererUrlQuery)({
    _fixtureId: fixtureId
  });
  return "".concat(host).concat(urlPath, "?").concat(query);
}

function getPlaygroundHost(_ref2) {
  var hostname = _ref2.hostname,
      port = _ref2.port;
  return "http://".concat(hostname || 'localhost', ":").concat(port);
}

function createFixtureElementGetter(fixture, fixturePath, decoratorsByPath) {
  var decorators = (0, _react.getSortedDecoratorsForFixturePath)(fixturePath, decoratorsByPath);
  return function () {
    return (0, _FixtureLoader.getDecoratedFixtureElement)(fixture, decorators, {
      fixtureState: {},
      setFixtureState: function setFixtureState() {},
      onErrorReset: function onErrorReset() {}
    });
  };
}